smartcard.pcsc.PCSCContext.PCSCContext.__PCSCContextSingleton

# ``smartcard`.`pcsc`.`PCSCContext`.`PCSCContext`.`__PCSCContextSingleton``

class documentation

`class __PCSCContextSingleton:`

View In Hierarchy

The actual pcsc context class as a singleton.

Method | `__init__` | Undocumented
Method | `getContext` | Undocumented
Method | `releaseContext` | Undocumented
Instance Variable | `hcontext` | Undocumented

def __init__(self):

Undocumented

def getContext(self):

Undocumented

def releaseContext(self):

Undocumented

hcontext =

Undocumented